# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"term": "00_ghtop.ipynb",
         "logfile": "00_ghtop.ipynb",
         "github_auth_device": "00_ghtop.ipynb",
         "limit_cb": "00_ghtop.ipynb",
         "api": "00_ghtop.ipynb",
         "Events": "00_ghtop.ipynb",
         "print_event": "00_ghtop.ipynb",
         "tail_events": "00_ghtop.ipynb",
         "watch_users": "00_ghtop.ipynb",
         "quad_logs": "00_ghtop.ipynb",
         "simple": "00_ghtop.ipynb",
         "main": "00_ghtop.ipynb"}

modules = ["ghtop.py"]

doc_url = "https://fastai.github.io/ghtop/"

git_url = "https://github.com/fastai/ghtop/tree/master/"

def custom_doc_links(name): return None
